@@ -20,7 +20,7 @@ import math,re,os,re,os,queue
 from threading import Thread
 from PIL import ImageDraw
 from .Generation import * 
-from .FunctionsPill import PillImg
+from .FunctionsPill import imagSize,imgD,centrText
 from .options import *
 from . import openFile
 try:
@@ -41,7 +41,7 @@ def openUserImg(img):
     elif type(img) == str:
         linkImg = re.search("(?P<url>https?://[^\s]+)", img)
         if linkImg:
-            img = PillImg(link=linkImg.group()).imgD()
+            img = imgD(link=linkImg.group())
         else:
             img = Image.open(f'{path}/{img}')
     else:
@@ -73,22 +73,22 @@ def weaponAdd(weaponRes,characters,lvlName):
         WeaponBg.paste(imageStats,(300,53),imageStats)
     
     stars = star(characters.detail.rarity)
-    image = PillImg(characters.detail.icon.url).imagSize(size = (114,121))
+    image = imagSize(link = characters.detail.icon.url,size = (114,121))
     WeaponBg.paste(image,(0,0),image)
     WeaponBg.paste(WeaponBgUp,(0,0),WeaponBgUp)
-    position,font = PillImg().centrText(name, witshRam = 315, razmer = 24, start = 159, Yram = 30, y = 13)
+    position,font = centrText(name, witshRam = 315, razmer = 24, start = 159, Yram = 30, y = 13)
     d.text(position, str(name), font= font, fill=coloring) 
     d.text((435 ,53), f"R{lvlUp}", font= t24, fill=(248,199,135,255)) 
-    position,font = PillImg().centrText(f"{lvlName}: {lvl}/90", witshRam = 152, razmer = 17, start = 235, Yram = 28, y = 90)
+    position,font = centrText(f"{lvlName}: {lvl}/90", witshRam = 152, razmer = 17, start = 235, Yram = 28, y = 90)
     d.text(position, f"{lvlName}: {lvl}/90", font= font, fill=coloring) 
 
-    position,font = PillImg().centrText(baseAtt, witshRam = 90, razmer = 24, start = 180, Yram = 30, y = 50)    
+    position,font = centrText(baseAtt, witshRam = 90, razmer = 24, start = 180, Yram = 30, y = 50)    
     d.text(position, str(baseAtt), font= font, fill=coloring)
     if proc:
-        position,font = PillImg().centrText(f'{dopStat}%', witshRam = 90, razmer = 24, start = 320, Yram = 30, y = 50)
+        position,font = centrText(f'{dopStat}%', witshRam = 90, razmer = 24, start = 320, Yram = 30, y = 50)
         d.text(position, f'{dopStat}%', font= font, fill=coloring)
     else:
-        position,font = PillImg().centrText(str(dopStat), witshRam = 90, razmer = 24, start = 320, Yram = 30, y = 50)
+        position,font = centrText(str(dopStat), witshRam = 90, razmer = 24, start = 320, Yram = 30, y = 50)
         d.text(position, str(dopStat), font= font, fill=coloring) 
     WeaponBg.paste(stars,(0,0),stars)
     weaponRes.put_nowait(WeaponBg)
@@ -96,10 +96,10 @@ def weaponAdd(weaponRes,characters,lvlName):
 def nameBanner(nameRes,characters,person,lvlName):
     NameBg = NameBgTeampleOne.copy()
     d = ImageDraw.Draw(NameBg)
-    centrName,fonts = PillImg().centrText(characters.name, witshRam = 220, razmer = 33,start = 2)
+    centrName,fonts = centrText(characters.name, witshRam = 220, razmer = 33,start = 2)
     d.text((centrName,28), characters.name, font = fonts, fill=coloring) 
     d.text((187,-1), str(characters.friendship_level), font = t24, fill= coloring) 
-    centrName,fonts = PillImg().centrText(f"{lvlName}: {characters.level}/90", witshRam = 148, razmer = 17, start = 5)
+    centrName,fonts = centrText(f"{lvlName}: {characters.level}/90", witshRam = 148, razmer = 17, start = 5)
     d.text((centrName,2), f"{lvlName}: {characters.level}/90", font = fonts, fill= coloring) 
     stars = star(person.rarity)
     NameBg.paste(stars,(63,68),stars)
@@ -138,14 +138,14 @@ def stats(statRes,characters,assets):
         d = ImageDraw.Draw(Attribute)
         
         txt = assets.get_hash_map(key[0])
-        icon = PillImg(image = iconImg).imagSize(fixed_width = 23)
+        icon = imagSize(image = iconImg,fixed_width = 23)
         Attribute.paste(icon, (4,0),icon)
 
         if not key[1].id in stat_perc:
             value = str(math.ceil(key[1].value))
         else:
             value = f"{round(key[1].value * 100, 1)}%"
-        pX,fnt = PillImg().centrText(value, witshRam = 119, razmer = 20, start = 325)
+        pX,fnt = centrText(value, witshRam = 119, razmer = 20, start = 325)
         d.text((pX,3), value, font = fnt, fill=coloring)
 
         d.text((42,4), str(txt), font = t18, fill=coloring)
@@ -158,7 +158,7 @@ def stats(statRes,characters,assets):
             dopStatVal  = dopVal[dopStatAtribute[key[0]]]
             dopStatValArtifact = int(key[1].value - dopStatVal)
             if dopStatValArtifact != 0:
-                pX,fnt = PillImg().centrText(f"{dopStatVal} + {dopStatValArtifact}", witshRam = 113, razmer = 13, start = 0)
+                pX,fnt = centrText(f"{dopStatVal} + {dopStatValArtifact}", witshRam = 113, razmer = 13, start = 0)
                 dv.text((pX,-1),f"{dopStatVal} + {dopStatValArtifact}", font = fnt, fill=(248,199,135))
                 AttributeBg.paste(dopValueBg,(354,postion[1]+27),dopValueBg)
 
@@ -171,7 +171,7 @@ def constant(rezConstant,characters,person):
         closeConstBg = ClossedBg.copy()
         closeConsticon = Clossed.copy()
         openConstBg = openImageElementConstant(person.element.value)  
-        imageIcon = PillImg(key.icon.url).imgD().resize((43,48))
+        imageIcon = imgD(link = key.icon.url).resize((43,48))
         if not key.unlocked:
             closeConstBg.paste(imageIcon, (19,20),imageIcon)
             closeConstBg.paste(closeConsticon, (0,0),closeConsticon)
@@ -186,9 +186,9 @@ def create_picture(rezFrame,person,imgs,adapt,splash = None):
         frame = userImage(imgs, element = person.element.value, adaptation = adapt)
     else:
         if splash:
-            banner = PillImg(link = splash).imagSize(size = (2048,1024))
+            banner = imagSize(link = splash,size = (2048,1024))
         else:
-            banner = PillImg(link = person.images.banner.url).imagSize(size = (2048,1024))
+            banner = imagSize(link = person.images.banner.url,size = (2048,1024))
             frame = maskaAdd(person.element.value,banner)
     rezFrame.put_nowait(frame)
 
@@ -202,10 +202,10 @@ def talants(talatsRes,characters):
             talantsBg = TalantsFrameTeampleOne.copy()
         talantsCount = TalantsCountTeampleOne.copy()
         d = ImageDraw.Draw(talantsCount)
-        imagesIconTalants = PillImg(link = key.icon.url).imgD().resize((50,50))
+        imagesIconTalants = imgD(link = key.icon.url).resize((50,50))
         talantsBg.paste(imagesIconTalants, (8,7),imagesIconTalants)
         talantsBg.paste(imagesIconTalants, (8,7),imagesIconTalants)
-        px,fnt = PillImg().centrText(key.level, witshRam = 25, razmer = 17, start = 3, Yram = 16, y = -1) 
+        px,fnt = centrText(key.level, witshRam = 25, razmer = 17, start = 3, Yram = 16, y = -1) 
         d.text(px, str(key.level), font = fnt, fill=(248,199,135,255))
         talantsBg.paste(talantsCount, (19,53),talantsCount)
         tallantsRes.append(talantsBg)
@@ -219,7 +219,7 @@ def naborArtifact(info,ArtifactNameBg,rezArtSet):
         if info[key] > 1:
             ArtifactNameFrame = ArtifactNameFrameTeampleOne.copy()
             d = ImageDraw.Draw(ArtifactNameFrame)
-            centrName,fonts = PillImg().centrText(key, witshRam = 240, razmer = 15, start = 4, Yram = 24, y = 1) 
+            centrName,fonts = centrText(key, witshRam = 240, razmer = 15, start = 4, Yram = 24, y = 1) 
             d.text(centrName, str(key), font= fonts, fill=coloring)
             d.text((267,-2), str(info[key]), font= t24, fill=coloring)
             naborAll.append(ArtifactNameFrame)
@@ -242,9 +242,9 @@ def creatDopStat(infpart,rezArtDop):
         v = f"+{key.value}"
         if str(key.type) == "DigitType.PERCENT":
             v = f"{v}%"
-        imageStats= PillImg(image = imageStats).imagSize(fixed_width = 17) 
+        imageStats= imagSize(image = imageStats,fixed_width = 17) 
         ArtifactDopStat.paste(imageStats,(3,1),imageStats)
-        px,fnt = PillImg().centrText(v, witshRam = 142, razmer = 24, start = 33) 
+        px,fnt = centrText(v, witshRam = 142, razmer = 24, start = 33) 
         d = ImageDraw.Draw(ArtifactDopStat)
         d.text((px,-2), v, font= fnt, fill=coloring)
         res.append(ArtifactDopStat)
@@ -256,7 +256,7 @@ def creatArtifact(artifacResSave,infpart,imageStats):
     Thread(target=creatDopStat,args=(infpart.detail.substats,rezArtDop)).start()
     ArtifactBgUp = openFile.ArtifactBgUpTeampleOne.copy()
     ArtifactBg = openFile.ArtifactBgTeampleOne.copy()
-    artimg = PillImg(infpart.detail.icon.url).imagSize(size = (175,175))
+    artimg = imagSize(link = infpart.detail.icon.url,size = (175,175))
     ArtifactBg.paste(artimg,(-32,-27),artimg)
     ArtifactBg.paste(ArtifactBgUp,(0,0),ArtifactBgUp)
     d = ImageDraw.Draw(ArtifactBg)
@@ -264,7 +264,7 @@ def creatArtifact(artifacResSave,infpart,imageStats):
         val = f"{infpart.detail.mainstats.value}%"
     else:
         val = infpart.detail.mainstats.value
-    centrName,fonts = PillImg().centrText(val, witshRam = 52, razmer = 17, start = 65)
+    centrName,fonts = centrText(val, witshRam = 52, razmer = 17, start = 65)
     d.text((centrName,62), str(val), font= fonts, fill=coloring)
     ArtifactBg.paste(imageStats,(3,0),imageStats)
     d.text((77,82), str(infpart.level), font= t17, fill=coloring)
