@@ -19,7 +19,7 @@ import math,queue
 
 from PIL import ImageDraw
 from .Generation import * 
-from .FunctionsPill import PillImg
+from .FunctionsPill import imagSize,centrText,imgD
 from .options import *
 from . import openFile
 from threading import Thread
@@ -29,9 +29,9 @@ def create_picture(rezFrame,person,imgs,adapt,splash = None):
         frame = userImageTwo(imgs, element = person.element.value, adaptation = adapt)
     else:
         if splash:
-            banner = PillImg(link = splash).imagSize(size = (1974,1048))
+            banner = imagSize(link = splash,size = (1974,1048))
         else:
-            banner = PillImg(link = person.images.banner.url).imagSize(size = (1974,1048))
+            banner = imagSize(link = person.images.banner.url,size = (1974,1048))
         frame = maskaAdd(person.element.value, banner, teample = 2)
     rezFrame.put_nowait(frame)
 
@@ -58,21 +58,21 @@ def weaponAdd(weaponRes,characters,lvlName):
         WeaponBg.paste(imageStats,(330,59),imageStats)
     
     stars = star(characters.detail.rarity)
-    image = PillImg(characters.detail.icon.url).imagSize(size = (131,138))
+    image = imagSize(link = characters.detail.icon.url,size = (131,138))
     WeaponBg.paste(image,(20,11),image)
-    position,font = PillImg().centrText(name, witshRam = 290, razmer = 24, start = 177, Yram = 38, y = 17)
+    position,font = centrText(name, witshRam = 290, razmer = 24, start = 177, Yram = 38, y = 17)
     d.text(position, str(name), font= font, fill=coloring) 
     d.text((195 ,111), str(lvlUp), font= t24, fill=(248,199,135,255)) 
-    position,font = PillImg().centrText(f"{lvlName['lvl']}: {lvl}/90", witshRam = 211, razmer = 24, start = 251, Yram = 38, y = 107)
+    position,font = centrText(f"{lvlName['lvl']}: {lvl}/90", witshRam = 211, razmer = 24, start = 251, Yram = 38, y = 107)
     d.text(position, f"{lvlName['lvl']}: {lvl}/90", font= font, fill=coloring) 
 
-    position,font = PillImg().centrText(baseAtt, witshRam = 131, razmer = 24, start = 167, Yram = 38, y = 56)    
+    position,font = centrText(baseAtt, witshRam = 131, razmer = 24, start = 167, Yram = 38, y = 56)    
     d.text(position, str(baseAtt), font= font, fill=coloring)
     if proc:
-        position,font = PillImg().centrText(f'{dopStat}%', witshRam = 131, razmer = 24, start = 333, Yram = 38, y = 56)
+        position,font = centrText(f'{dopStat}%', witshRam = 131, razmer = 24, start = 333, Yram = 38, y = 56)
         d.text(position, f'{dopStat}%', font= font, fill=coloring)
     else:
-        position,font = PillImg().centrText(str(dopStat), witshRam = 131, razmer = 24, start = 333, Yram = 38, y = 56)
+        position,font = centrText(str(dopStat), witshRam = 131, razmer = 24, start = 333, Yram = 38, y = 56)
         d.text(position, str(dopStat), font= font, fill=coloring) 
     WeaponBg.paste(stars,(10,135),stars)
     
@@ -81,10 +81,10 @@ def weaponAdd(weaponRes,characters,lvlName):
 def nameBanner(nameRes,characters,lvlName):
     NameBg = openFile.NameBgTeampleTwo.copy()
     d = ImageDraw.Draw(NameBg)
-    centrName,fonts = PillImg().centrText(characters.name, witshRam = 244, razmer = 24,start = 19, Yram = 29, y = 0)
+    centrName,fonts = centrText(characters.name, witshRam = 244, razmer = 24,start = 19, Yram = 29, y = 0)
     d.text((centrName,1), characters.name, font = fonts, fill=coloring) 
     d.text((33,47), str(characters.friendship_level), font = t24, fill= coloring) 
-    centrName,fonts = PillImg().centrText(f"{lvlName['lvl']}: {characters.level}/90", witshRam = 209, razmer = 24, start = 77)
+    centrName,fonts = centrText(f"{lvlName['lvl']}: {characters.level}/90", witshRam = 209, razmer = 24, start = 77)
     d.text((centrName,47), f"{lvlName['lvl']}: {characters.level}/90", font = fonts, fill= coloring) 
     
     nameRes.put_nowait(NameBg)
@@ -131,7 +131,7 @@ def stats(statRes,characters,assets):
         Attribute = openFile.AttributeTeampleTwo.copy()
         d = ImageDraw.Draw(Attribute)
         
-        icon = PillImg(image = iconImg).imagSize(fixed_width = 26)
+        icon = imagSize(image = iconImg,fixed_width = 26)
 
         Attribute.paste(icon, (10,4),icon)
 
@@ -139,7 +139,7 @@ def stats(statRes,characters,assets):
             value = str(math.ceil(key[1].value))
         else:
             value = f"{round(key[1].value * 100, 1)}%"
-        pX,fnt = PillImg().centrText(value, witshRam = 151, razmer = 24, start = 410)
+        pX,fnt = centrText(value, witshRam = 151, razmer = 24, start = 410)
         d.text((pX,7), value, font = fnt, fill=coloring)
 
         d.text((67,7), str(txt), font = t24, fill=coloring)
@@ -162,7 +162,7 @@ def constant(rezConstant,characters,person):
         closeConstBg = ClossedBg.copy()
         closeConsticon = Clossed.copy()
         openConstBg = openImageElementConstant(person.element.value)
-        imageIcon = PillImg(key.icon.url).imgD().resize((43,48))
+        imageIcon = imgD(link = key.icon.url).resize((43,48))
         if not key.unlocked:
             closeConstBg.paste(imageIcon, (19,20),imageIcon)
             closeConstBg.paste(closeConsticon, (0,0),closeConsticon)
@@ -184,9 +184,9 @@ def talants(talatsRes,characters):
             talantsBg = TalantsFrameTeampleTwo.copy()
         talantsCount = TalantsCountTeampleTwo.copy()
         d = ImageDraw.Draw(talantsCount)
-        imagesIconTalants = PillImg(link = key.icon.url).imgD().resize((52,52))
+        imagesIconTalants = imgD(link = key.icon.url).resize((52,52))
         talantsBg.paste(imagesIconTalants, (7,6),imagesIconTalants)
-        px,fnt = PillImg().centrText(key.level, witshRam = 25, razmer = 18, start = 1, Yram = 25, y = 1) 
+        px,fnt = centrText(key.level, witshRam = 25, razmer = 18, start = 1, Yram = 25, y = 1) 
         d.text(px, str(key.level), font = fnt, fill=(248,199,135,255))
         talantsBg.paste(talantsCount, (20,47),talantsCount)
         tallantsRes.append(talantsBg)
@@ -202,7 +202,7 @@ def naborArtifact(rezArtSet,info,ArtifactNameBg):
         if info[key] > 1:
             ArtifactNameFrame = openFile.ArtifactNameFrameTeampleTwo.copy()
             d = ImageDraw.Draw(ArtifactNameFrame)
-            centrName,fonts = PillImg().centrText(key, witshRam = 289, razmer = 24, start = 2, Yram = 28, y = 1) 
+            centrName,fonts = centrText(key, witshRam = 289, razmer = 24, start = 2, Yram = 28, y = 1) 
             d.text(centrName, str(key), font= fonts, fill=coloring)
             d.text((356,0), str(info[key]), font= t24, fill=coloring)
             naborAll.append(ArtifactNameFrame)
@@ -219,7 +219,7 @@ def naborArtifact(rezArtSet,info,ArtifactNameBg):
 def creatArtifact(artifacResSave,infpart,imageStats):
     ArtifactBg = openFile.ArtifactBgTeampleTwo.copy()
     ArtifactUp = openFile.ArtifactBgUpTeampleTwo.copy()
-    artimg = PillImg(infpart.detail.icon.url).imagSize(size = (120,107))
+    artimg = imagSize(link = infpart.detail.icon.url,size = (120,107))
     ArtifactBg.paste(artimg,(-5,0),artimg)
     ArtifactBg.paste(ArtifactUp,(0,0),ArtifactUp)
     d = ImageDraw.Draw(ArtifactBg)
@@ -227,7 +227,7 @@ def creatArtifact(artifacResSave,infpart,imageStats):
         val = f"{infpart.detail.mainstats.value}%"
     else:
         val = infpart.detail.mainstats.value
-    centrName,fonts = PillImg().centrText(val, witshRam = 62, razmer = 17, start = 53)
+    centrName,fonts = centrText(val, witshRam = 62, razmer = 17, start = 53)
     d.text((centrName,77), str(val), font= fonts, fill=coloring)
     
     ArtifactBg.paste(imageStats,(7,2),imageStats)
@@ -246,7 +246,7 @@ def creatArtifact(artifacResSave,infpart,imageStats):
         imageStats = getIconAdd(key.prop_id, icon = True)
         if not imageStats:
             continue
-        imageStats= PillImg(image = imageStats).imagSize(fixed_width = 24) 
+        imageStats= imagSize(image = imageStats,fixed_width = 24) 
         ArtifactBgStat.paste(imageStats,(3,1),imageStats)
         d.text((57,2), v, font= t24, fill=coloring)
         ArtifactBg.paste(ArtifactBgStat,positionIcon,ArtifactBgStat)
@@ -295,24 +295,21 @@ def artifacAdd(rezArt,rezArtSet,characters):
 
 def creatUserInfo(hide,uid,player,lang, nameCharter = None, namecard = False):
     if not namecard:
-        bannerUserNamecard = PillImg(link = player.namecard.banner.url).imagSize(size = (601,283))
+        bannerUserNamecard = imagSize(link = player.namecard.banner.url,size = (601,283))
     else:
         linkImgCard = f"https://enka.network/ui/UI_NameCardPic_{nameCharter}_P.png"
-        bannerUserNamecard = PillImg(link = linkImgCard).imagSize(size = (601,283))
+        bannerUserNamecard = imagSize(link = linkImgCard,size = (601,283))
     bannerUserNamecard = bannerUserNamecard.crop((0, 32, 601, 255))
     defoldBgNamecard = openFile.infoUserBgTeampleTwo.copy()
     maskaBannerNamecard = openFile.infoUserMaskaTeampleTwo.copy()
     defoldBgNamecard = Image.composite(defoldBgNamecard, bannerUserNamecard, maskaBannerNamecard)
     frameUserNamecard = openFile.infoUserFrameTeampleTwo.copy()
     defoldBgNamecard.paste(openFile.infoUserFrameBannerTeampleTwo,(0,0),openFile.infoUserFrameBannerTeampleTwo)
-    try:
-        avatar = PillImg(link = player.icon.url.url).imagSize(size = (150,150)) 
-    except:
-        avatar = PillImg(link = player.avatar.icon.url).imagSize(size = (150,150))
+    avatar = imagSize(link = player.avatar.icon.url,size = (150,150))
     avatar = Image.composite(frameUserNamecard, avatar, openFile.infoUserMaskaAvatarTeampleTwo)
     frameUserNamecard.paste(avatar,(0,0),avatar)
     d = ImageDraw.Draw(frameUserNamecard)
-    centrName,fonts = PillImg().centrText(player.nickname, witshRam = 150, razmer = 19, start = 0)
+    centrName,fonts = centrText(player.nickname, witshRam = 150, razmer = 19, start = 0)
     d.text((centrName,155), player.nickname, font= fonts, fill=coloring)
     d.text((163,34), f"{lang['AR']}:{player.level}", font= fonts, fill=coloring)
     d.text((163,65), f"{lang['WL']}:{player.world_level}", font= fonts, fill=coloring)
