@@ -22,7 +22,7 @@ def centryImage(userImages, teample = 1):
             return userImages, -int(userImages.size[0]/2-300)
         else:
             return userImages, -int(userImages.size[0]/2*0.2)
-    else:
+    elif teample == 2:
         x,y = userImages.size
         baseheight = 1500
 
@@ -36,78 +36,133 @@ def centryImage(userImages, teample = 1):
             return userImages, 0
         else:
             return userImages, 555
+    else:
+        x,y = userImages.size
+        baseheight = 1337
+
+        if x > y or x == y:
+            baseheight = 802
+        hpercent = (baseheight / float (y)) 
+        wsize = int ((float (x) * float (hpercent)))
+        userImages = userImages.resize ((wsize, baseheight), Image.ANTIALIAS) 
+
+        if x > y or x == y:
+            return userImages, 0
+        else:
+            return userImages, 0
 
 def openImageElement(element,teample = 1):
     if teample == 1:
         if element == "Fire":
-            return PyroBgTeampleOne.copy()
+            bg = PyroBgTeampleOne.copy()
         elif element== "Grass":
-            return DendroBgTeampleOne.copy()
+            bg = DendroBgTeampleOne.copy()
         elif element == "Electric":
-            return ElectroBgTeampleOne.copy()
+            bg = ElectroBgTeampleOne.copy()
         elif element == "Water":
-            return GydroBgTeampleOne.copy()
+            bg = GydroBgTeampleOne.copy()
         elif element == "Wind":
-            return AnemoBgTeampleOne.copy()
+            bg = AnemoBgTeampleOne.copy()
         elif element== "Rock":
-            return GeoBgTeampleOne.copy()
+            bg = GeoBgTeampleOne.copy()
         elif element == "Ice":
-            return CryoBgTeampleOne.copy()
+            bg = CryoBgTeampleOne.copy()
         else:
-            return ErrorBgTeampleOne.copy()
+            bg = ErrorBgTeampleOne.copy()
+    elif teample == 2:
+        if element == "Fire":
+            bg = PyroBgTeampleTwo.copy()
+        elif element== "Grass":
+            bg = DendroBgTeampleTwo.copy()
+        elif element == "Electric":
+            bg = ElectroBgTeampleTwo.copy()
+        elif element == "Water":
+            bg = GydroBgTeampleTwo.copy()
+        elif element == "Wind":
+            bg = AnemoBgTeampleTwo.copy()
+        elif element== "Rock":
+            bg = GeoBgTeampleTwo.copy()
+        elif element == "Ice":
+            bg = CryoBgTeampleTwo.copy() 
+        else:
+            bg = ErrorBgTeampleTwo.copy()
     else:
         if element == "Fire":
-            return PyroBgTeampleTwo.copy()
+            bg = PyroBgTeampleTree.copy()
         elif element== "Grass":
-            return DendroBgTeampleTwo.copy()
+            bg = DendroBgTeampleTree.copy()
         elif element == "Electric":
-            return ElectroBgTeampleTwo.copy()
+            bg = ElectroBgTeampleTree.copy()
         elif element == "Water":
-            return GydroBgTeampleTwo.copy()
+            bg = GydroBgTeampleTree.copy()
         elif element == "Wind":
-            return AnemoBgTeampleTwo.copy()
+            bg = AnemoBgTeampleTree.copy()
         elif element== "Rock":
-            return GeoBgTeampleTwo.copy()
+            bg = GeoBgTeampleTree.copy()
         elif element == "Ice":
-            return CryoBgTeampleTwo.copy()
+            bg = CryoBgTeampleTree.copy()
         else:
-            return ErrorBgTeampleTwo.copy()
-
-def openImageElementConstant(element):
-    if element == "Fire":
-        return PyroConstant.copy()
-    elif element== "Grass":
-        return DendroConstant.copy()
-    elif element == "Electric":
-        return ElectroConstant.copy()
-    elif element == "Water":
-        return GydroConstant.copy()
-    elif element == "Wind":
-        return AnemoConstant.copy()
-    elif element== "Rock":
-        return GeoConstant.copy()
-    elif element == "Ice":
-        return CryoConstant.copy()
+            bg = ErrorBgTeampleTree.copy()
+    return bg
+def openImageElementConstant(element, teampt = 1):
+    if teampt in [1,2]:
+        if element == "Fire":
+            return PyroConstant.copy()
+        elif element== "Grass":
+            return DendroConstant.copy()
+        elif element == "Electric":
+            return ElectroConstant.copy()
+        elif element == "Water":
+            return GydroConstant.copy()
+        elif element == "Wind":
+            return AnemoConstant.copy()
+        elif element== "Rock":
+            return GeoConstant.copy()
+        elif element == "Ice":
+            return CryoConstant.copy()
+        else:
+            return ErrorConstant.copy()
     else:
-        return ErrorConstant.copy()
-
+        if element == "Fire":
+            return PyroConstantOpen.copy(),PyroConstantClosed.copy()
+        elif element== "Grass":
+            return DendroConstantOpen.copy(),DendroConstantClosed.copy()
+        elif element == "Electric":
+            return ElectroConstantOpen.copy(), ElectroConstantClosed.copy()
+        elif element == "Water":
+            return GydroConstantOpen.copy(),GydroConstantClosed.copy()
+        elif element == "Wind":
+            return AnemoConstantOpen.copy(), AnemoConstantClosed.copy()
+        elif element== "Rock":
+            return GeoConstantOpen.copy(), GeoConstantClosed.copy()
+        elif element == "Ice":
+            return CryoConstantOpen.copy(), CryoConstantClosed.copy()
+        else:
+            return ErrorConstantOpen.copy(), ErrorConstantClosed.copy()
+            
 def maskaAdd(element,charter, teample = 1):
     if teample == 1:
         bg = openImageElement(element)
         bgUP = bg.copy()
         bg.paste(charter,(-734,-134),charter)
-        im = Image.composite(bg, bgUP, MaskaBgTeampleOne)
+        im = Image.composite(bg, bgUP, MaskaBgTeampleOne.copy())
         bg.paste(im,(0,0))
-    else:
+    elif teample == 2:
         bg = openImageElement(element, teample = 2)
         bgUP = bg.copy()
         bg.paste(charter,(0,0),charter)
-        im = Image.composite(bg, bgUP, MaskaSplas)
+        im = Image.composite(bg, bgUP, MaskaSplas.copy())
         bg.paste(im,(0,0))
-        bg.paste(MasskaEffectDown,(0,0),MasskaEffectDown)
+        bg.paste(MasskaEffectDown.copy(),(0,0),MasskaEffectDown.copy())
+    else:
+        bg = openImageElement(element, teample = 3)
+        bgUP = bg.copy()
+        bg.paste(charter,(-810,-115),charter)
+        im = Image.composite(bg, bgUP, UserBgTeampleTree.copy())
+        bg.paste(im,(0,0))
+        bg.paste(EffectBgTeampleTree.copy(),(0,0),EffectBgTeampleTree.copy())
     return bg
 
-@cached(cache=TTLCache(maxsize=1024, ttl=600))
 def userImage(img,element = None, adaptation = False):
     userImagess,pozitionX = centryImage(img)
     if adaptation:
@@ -115,7 +170,7 @@ def userImage(img,element = None, adaptation = False):
         Effect = UserEffectTeampleOne.copy()
         grandient = ImageChops.screen(grandient,Effect)
         Effect.paste(userImagess,(pozitionX,0),userImagess)
-        im = Image.composite(Effect, grandient, MaskaUserBg2TeampleOne)
+        im = Image.composite(Effect, grandient, MaskaUserBg2TeampleOne.copy())
         return im
     else:
         try:
@@ -125,11 +180,31 @@ def userImage(img,element = None, adaptation = False):
             print(e)
 
         bg.paste(userImagess,(pozitionX,0))
-        im = Image.composite(bg, effect, MaskaUserBg2TeampleOne)
+        im = Image.composite(bg, effect, MaskaUserBg2TeampleOne.copy())
         bg.paste(im,(0,0))
         return bg
 
-@cached(cache=TTLCache(maxsize=1024, ttl=600))
+
+def userImageTree(img,element = None, adaptation = False):
+    userImagess,pozitionX = centryImage(img, teample = 3)
+    if adaptation:
+        grandient = userAdaptGrandient(userImagess.convert("RGB").copy(), size =(1924,802))
+        Effect = EffectBgTree.copy()
+        grandient = ImageChops.screen(grandient,Effect)
+        Effect.paste(userImagess,(pozitionX,0),userImagess)
+        im = Image.composite(Effect, grandient, UserBgTeampleImgTree.copy())
+        im.paste(EffectBgTeampleTree.copy(),(0,0),EffectBgTeampleTree.copy())
+        return im
+    else:
+        bg = openImageElement(element, teample = 3)
+        effect = bg.copy()
+        bg.paste(userImagess,(pozitionX,0),userImagess)
+        im = Image.composite(bg, effect, UserBgTeampleImgTree.copy())
+        bg.paste(im,(0,0))
+        bg.paste(EffectBgTeampleTree.copy(),(0,0),EffectBgTeampleTree.copy())
+        return bg
+
+
 def userImageTwo(img,element = None, adaptation = False):
     userImagess,pozitionX = centryImage(img, teample = 2)
     if adaptation:
@@ -141,16 +216,17 @@ def userImageTwo(img,element = None, adaptation = False):
         Effect = UserEffectTeampleTwo.copy()
         grandient = ImageChops.screen(bg,Effect)
         Effect.paste(userImagess,(pozitionX,0),userImagess)
-        im = Image.composite(Effect, grandient, UserBgTeampleTwo)
+        im = Image.composite(Effect, grandient, UserBgTeampleTwo.copy())
         return im
     else:
         bg = openImageElement(element, teample = 2)
         effect = bg.copy()
         bg.paste(userImagess,(pozitionX,0),userImagess)
-        im = Image.composite(bg, effect, UserBgTeampleTwo)
+        im = Image.composite(bg, effect, UserBgTeampleTwo.copy())
         bg.paste(im,(0,0))
         return bg
 
+
 '''
 def userImageBlur(img,element = None, adaptation = False):
     userImagess,pozitionX = centryImage(img)
@@ -170,39 +246,40 @@ def userImageBlur(img,element = None, adaptation = False):
         img.paste(im,(0,0))
         return img
 '''
+
 @cached(cache=TTLCache(maxsize=1024, ttl=600))
 def star(x):
     if x == 1:
-        imgs = Star1
+        imgs = Image.open(f'{path}/stars/Star1.png')
     elif x == 2:
-        imgs = Star2
+        imgs = Image.open(f'{path}/stars/Star2.png')
     elif x == 3:
-        imgs = Star3
+        imgs = Image.open(f'{path}/stars/Star3.png')
     elif x == 4:
-        imgs = Star4
+        imgs = Image.open(f'{path}/stars/Star4.png')
     elif x == 5:
-        imgs = Star5
+        imgs = Image.open(f'{path}/stars/Star5.png')
 
     return imgs.copy()
 
-@cached(cache=TTLCache(maxsize=1024, ttl=600))
+
 def elementIconPanel(element):
     if element == "Fire":
-        return PyroCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/PYRO.png')
     elif element== "Grass":
-        return DendroCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/DENDRO.png')
     elif element == "Electric":
-        return ElectoCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/ELECTRO.png')
     elif element == "Water":
-        return GydroCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/GYDRO.png')
     elif element == "Wind":
-        return AnemoCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/ANEMO.png')
     elif element== "Rock":
-        return GeoCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/GEO.png')
     elif element == "Ice":
-        return CryoCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/CRYO.png')
     else:
-        return PyroCharterElementTeampleTwo.copy()
+        return Image.open(f'{path}/teapmleTwo/charter_element/PYRO.png')
 
 @cached(cache=TTLCache(maxsize=1024, ttl=600))
 def getIconAdd(x, icon = False, size = None):
@@ -210,47 +287,47 @@ def getIconAdd(x, icon = False, size = None):
         if not x in IconAddTrue:
             return False
     if x == "FIGHT_PROP_MAX_HP" or x == "FIGHT_PROP_HP":
-        icons = FIGHT_PROP_MAX_HP 
+        icons = Image.open(f'{path}/icon/HP.png')  
     elif x == "FIGHT_PROP_CUR_ATTACK" or x =="FIGHT_PROP_ATTACK":
-        icons = FIGHT_PROP_CUR_ATTACK
+        icons = Image.open(f'{path}/icon/ATTACK.png')
     elif x == "FIGHT_PROP_CUR_DEFENSE" or x == "FIGHT_PROP_DEFENSE":
-        icons = FIGHT_PROP_CUR_DEFENSE
+        icons = Image.open(f'{path}/icon/DEFENSE.png')
     elif x == "FIGHT_PROP_ELEMENT_MASTERY":
-        icons = FIGHT_PROP_ELEMENT_MASTERY
+        icons = Image.open(f'{path}/icon/MASTERY.png')
     elif x == "FIGHT_PROP_CRITICAL":
-        icons = FIGHT_PROP_CRITICAL
+        icons = Image.open(f'{path}/icon/CRITICAL_HURT.png')
     elif x == "FIGHT_PROP_CRITICAL_HURT":
-        icons = FIGHT_PROP_CRITICAL_HURT
+        icons = Image.open(f'{path}/icon/CRITICAL.png')
     elif x == "FIGHT_PROP_CHARGE_EFFICIENCY":
-        icons = FIGHT_PROP_CHARGE_EFFICIENCY
+        icons = Image.open(f'{path}/icon/CHARGE_EFFICIENCY.png')
     elif x == "FIGHT_PROP_ELEC_ADD_HURT":
-        icons = FIGHT_PROP_ELEC_ADD_HURT
+        icons = Image.open(f'{path}/icon/ELECTRO.png')
     elif x == "FIGHT_PROP_DEFENSE_PERCENT":
-        icons = FIGHT_PROP_DEFENSE_PERCENT
+        icons = Image.open(f'{path}/icon/DEFENSE_PERCENT.png')
     elif x == "FIGHT_PROP_ATTACK_PERCENT":
-        icons = FIGHT_PROP_ATTACK_PERCENT
+        icons = Image.open(f'{path}/icon/ATTACK_PERCENT.png')
     elif x == "FIGHT_PROP_HP_PERCENT":
-        icons = FIGHT_PROP_HP_PERCENT
+        icons = Image.open(f'{path}/icon/HP_PERCENT.png')
     elif x == "FIGHT_PROP_WATER_ADD_HURT":
-        icons = FIGHT_PROP_WATER_ADD_HURT
+        icons = Image.open(f'{path}/icon/HYDRO.png')
     elif x == "FIGHT_PROP_WIND_ADD_HURT":
-        icons = FIGHT_PROP_WIND_ADD_HURT
+        icons = Image.open(f'{path}/icon/ANEMO.png')
     elif x == "FIGHT_PROP_ICE_ADD_HURT":
-        icons = FIGHT_PROP_ICE_ADD_HURT
+        icons = Image.open(f'{path}/icon/CRYO.png')
     elif x == "FIGHT_PROP_ROCK_ADD_HURT":
-        icons = FIGHT_PROP_ROCK_ADD_HURT
+        icons = Image.open(f'{path}/icon/GEO.png')
     elif x == "FIGHT_PROP_FIRE_ADD_HURT":
-        icons = FIGHT_PROP_FIRE_ADD_HURT
+        icons = Image.open(f'{path}/icon/PYRO.png')
     elif x == "FIGHT_PROP_GRASS_ADD_HURT":
-        icons = FIGHT_PROP_GRASS_ADD_HURT
+        icons = Image.open(f'{path}/icon/DENDRO.png')
     elif x == "FIGHT_PROP_HEAL_ADD":
-        icons = FIGHT_PROP_HEAL_ADD
+        icons = Image.open(f'{path}/icon/HEALED_ADD.png')
     elif x == "FIGHT_PROP_HEAL":
-        icons = FIGHT_PROP_HEAL
+        icons = Image.open(f'{path}/icon/HEAL.png')
     else:
         return False
     if size:
         icons.thumbnail(size)
         return icons.convert("RGBA").copy()
     else:
-        return icons.convert("RGBA").copy()
+        return icons.convert("RGBA").copy()
\ No newline at end of file
